package com.module.breeze

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.size
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.rounded.AcUnit
import androidx.compose.material.icons.rounded.Air
import androidx.compose.material.icons.rounded.ArrowDownward
import androidx.compose.material.icons.rounded.ArrowDropDown
import androidx.compose.material.icons.rounded.ArrowUpward
import androidx.compose.material.icons.rounded.KeyboardArrowDown
import androidx.compose.material.icons.rounded.KeyboardArrowUp
import androidx.compose.material.icons.rounded.LocationOn
import androidx.compose.material.icons.rounded.Map
import androidx.compose.material.icons.rounded.WaterDrop
import androidx.compose.material.icons.sharp.KeyboardArrowDown
import androidx.compose.material.icons.twotone.AccountCircle
import androidx.compose.material3.Icon
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.draw.alpha
import androidx.compose.ui.text.font.FontWeight
import androidx.compose.ui.tooling.preview.Preview
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import com.module.breeze.ui.theme.BreezeTheme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContent {
            BreezeTheme {
                Scaffold(modifier = Modifier.fillMaxSize()) { innerPadding ->
                    WeatherInfo(
                        modifier = Modifier.padding(innerPadding)
                    )
                }
            }
        }
    }
}

@Composable
fun WeatherInfo(modifier: Modifier = Modifier) {
    val fontSizeCurrentTemp = 48.sp
    val fontSizeUpper = 16.sp
    val breezeFontWeight = FontWeight.Bold
    val iconStyle = Icons.Rounded;

    var displayRain = false;
    var displaySnow = false;
    var displayWind = false;

    Column(
        modifier = Modifier.fillMaxSize(),
        verticalArrangement = Arrangement.Center,
        horizontalAlignment = Alignment.CenterHorizontally,
    ) {
        Row(verticalAlignment = Alignment.Bottom)
        {
            Icon(
                imageVector = iconStyle.Map,
                contentDescription = "Location Icon",
                modifier = Modifier
                    .padding(end = 16.dp)
                    .size(32.dp)
            )
            Icon(
                imageVector = iconStyle.WaterDrop,
                contentDescription = "Rain Icon",
                modifier = Modifier.alpha(if (displayRain) 1F else 0.2F)
            )
            Icon(
                imageVector = iconStyle.AcUnit,
                contentDescription = "Snow Icon",
                modifier = Modifier.alpha(if (displaySnow) 1F else 0.2F)
            )

            Icon(
                imageVector = iconStyle.Air,
                contentDescription = "Wind Icon",
                modifier = Modifier.alpha(if (displayWind) 1F else 0.2F)
            )
        }
        Row {
            Icon(
                imageVector = iconStyle.ArrowDownward,
                contentDescription = "Arrow down Icon"
            )
            Text(
                text = "18°",
                fontSize = fontSizeUpper,
                fontWeight = breezeFontWeight
            )
            Icon(
                imageVector = iconStyle.ArrowUpward,
                contentDescription = "Arrow up Icon"
            )
            Text(
                text = "23°",
                fontSize = fontSizeUpper,
                fontWeight = breezeFontWeight
            )
        }
        Text(
            text = "15°",
            fontSize = fontSizeCurrentTemp,
            fontWeight = breezeFontWeight,
        )
    }
}

@Preview(showBackground = true)
@Composable
fun GreetingPreview() {
    BreezeTheme {
        WeatherInfo()
    }
}